// generated from rosidl_adapter/resource/srv.idl.em
// with input from rosbag2_interfaces/srv/GetRate.srv
// generated code does not contain a copyright notice


module rosbag2_interfaces {
  module srv {
    struct GetRate_Request {
      uint8 structure_needs_at_least_one_member;
    };
    struct GetRate_Response {
      double rate;
    };
  };
};
